summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authormatt dannenberg <matt.dannenberg@10gen.com>2014-05-30 06:24:30 -0400
committerEric Milkie <milkie@10gen.com>2014-05-30 13:22:22 -0400
commitc73f7c12cde09575b11db1dba91d852c724d076c (patch)
treecc800a6e8daddac5665a9d1b8c6ea6e610340cad
parentb1950f5fa70b5ac93f83546f8a49e64e58a35a31 (diff)
downloadmongo-c73f7c12cde09575b11db1dba91d852c724d076c.tar.gz
SERVER-14092 ignore local.replset.minvalid in upgradeChecker
(cherry picked from commit 79c5492d92e661e169d852c218ec393f31337db7)
-rw-r--r--src/mongo/shell/upgrade_check.js20
1 files changed, 16 insertions, 4 deletions
diff --git a/src/mongo/shell/upgrade_check.js b/src/mongo/shell/upgrade_check.js
index 3f189d67d25..17482755c09 100644
--- a/src/mongo/shell/upgrade_check.js
+++ b/src/mongo/shell/upgrade_check.js
@@ -69,10 +69,22 @@ var collUpgradeCheck = function(collObj) {
}
});
- // do not validate the documents in config dbs, oplog, or system collections
- if (collName.indexOf("system.") === 0 ||
- dbName === "config" ||
- (dbName === "local" && collName.indexOf("oplog.") === 0)) {
+ // do not validate the documents in system collections
+ if (collName.indexOf("system.") === 0) {
+ return goodSoFar;
+ }
+ // do not validate the documents in config dbs
+ if (dbName === "config") {
+ return goodSoFar;
+ }
+
+ // do not validate the documents in the oplog collection
+ if (dbName === "local" && collName.indexOf("oplog.") === 0) {
+ return goodSoFar;
+ }
+
+ // do not validate the documents in the minvalid collection
+ if (dbName === "local" && collName.indexOf("replset.minvalid") === 0) {
return goodSoFar;
}